@@ -8,7 +8,6 @@ from sklearn.base import clone
 from sklearn.model_selection import cross_validate
 from sklearn.base import is_classifier, is_regressor
 from sklearn.utils import check_X_y
-from sklearn.utils.metaestimators import if_delegate_has_method
 from sklearn.utils.validation import check_is_fitted
 from sklearn.metrics import check_scoring
 from sklearn.exceptions import NotFittedError
@@ -20,6 +19,7 @@ from .parameters import Algorithms, Criteria
 from .space import Space
 from .algorithms import eaSimple, eaMuPlusLambda, eaMuCommaLambda
 from .callbacks.validations import check_callback
+from .schedules.validations import check_adapter
 from .utils.cv_scores import (
     create_gasearch_cv_results_,
     create_feature_selection_cv_results_,
@@ -71,10 +71,10 @@ class GASearchCV(BaseSearchCV):
     generations : int, default=40
         Number of generations or iterations to run the evolutionary algorithm.
 
-    crossover_probability : float, default=0.8
+    crossover_probability : float or a Scheduler, default=0.8
         Probability of crossover operation between two individuals.
 
-    mutation_probability : float, default=0.1
+    mutation_probability : float or a Scheduler, default=0.1
         Probability of child mutation.
 
     tournament_size : int, default=3
@@ -217,8 +217,8 @@ class GASearchCV(BaseSearchCV):
         scoring=None,
         population_size=50,
         generations=80,
-        crossover_probability=0.8,
-        mutation_probability=0.2,
+        crossover_probability=0.2,
+        mutation_probability=0.8,
         tournament_size=3,
         elitism=True,
         verbose=True,
@@ -241,6 +241,8 @@ class GASearchCV(BaseSearchCV):
         self.generations = generations
         self.crossover_probability = crossover_probability
         self.mutation_probability = mutation_probability
+        self.crossover_adapter = check_adapter(self.crossover_probability)
+        self.mutation_adapter = check_adapter(self.mutation_probability)
         self.tournament_size = tournament_size
         self.elitism = elitism
         self.verbose = verbose
@@ -467,7 +469,6 @@ class GASearchCV(BaseSearchCV):
 
         return [score]
 
-    @if_delegate_has_method(delegate="estimator")
     def fit(self, X, y, callbacks=None):
         """
         Main method of GASearchCV, starts the optimization
@@ -601,9 +602,9 @@ class GASearchCV(BaseSearchCV):
             pop, log, gen = eaSimple(
                 pop,
                 self.toolbox,
-                cxpb=self.crossover_probability,
+                cxpb=self.crossover_adapter,
                 stats=stats,
-                mutpb=self.mutation_probability,
+                mutpb=self.mutation_adapter,
                 ngen=self.generations,
                 halloffame=hof,
                 callbacks=self.callbacks,
@@ -618,9 +619,9 @@ class GASearchCV(BaseSearchCV):
                 self.toolbox,
                 mu=self.population_size,
                 lambda_=2 * self.population_size,
-                cxpb=self.crossover_probability,
+                cxpb=self.crossover_adapter,
                 stats=stats,
-                mutpb=self.mutation_probability,
+                mutpb=self.mutation_adapter,
                 ngen=self.generations,
                 halloffame=hof,
                 callbacks=self.callbacks,
@@ -634,9 +635,9 @@ class GASearchCV(BaseSearchCV):
                 self.toolbox,
                 mu=self.population_size,
                 lambda_=2 * self.population_size,
-                cxpb=self.crossover_probability,
+                cxpb=self.crossover_adapter,
                 stats=stats,
-                mutpb=self.mutation_probability,
+                mutpb=self.mutation_adapter,
                 ngen=self.generations,
                 halloffame=hof,
                 callbacks=self.callbacks,
@@ -754,10 +755,10 @@ class GAFeatureSelectionCV(BaseSearchCV):
     generations : int, default=40
         Number of generations or iterations to run the evolutionary algorithm.
 
-    crossover_probability : float, default=0.8
+    crossover_probability : float or a Scheduler, default=0.2
         Probability of crossover operation between two individuals.
 
-    mutation_probability : float, default=0.1
+    mutation_probability : float or a Scheduler, default=0.8
         Probability of child mutation.
 
     tournament_size : int, default=3
@@ -897,8 +898,8 @@ class GAFeatureSelectionCV(BaseSearchCV):
         scoring=None,
         population_size=50,
         generations=80,
-        crossover_probability=0.8,
-        mutation_probability=0.2,
+        crossover_probability=0.2,
+        mutation_probability=0.8,
         tournament_size=3,
         elitism=True,
         max_features=None,
@@ -922,6 +923,8 @@ class GAFeatureSelectionCV(BaseSearchCV):
         self.generations = generations
         self.crossover_probability = crossover_probability
         self.mutation_probability = mutation_probability
+        self.crossover_adapter = check_adapter(self.crossover_probability)
+        self.mutation_adapter = check_adapter(self.mutation_probability)
         self.tournament_size = tournament_size
         self.elitism = elitism
         self.max_features = max_features
@@ -1121,7 +1124,6 @@ class GAFeatureSelectionCV(BaseSearchCV):
 
         return [score, n_selected_features]
 
-    @if_delegate_has_method(delegate="estimator")
     def fit(self, X, y, callbacks=None):
         """
         Main method of GAFeatureSelectionCV, starts the optimization
@@ -1144,7 +1146,7 @@ class GAFeatureSelectionCV(BaseSearchCV):
         self.n_features = X.shape[1]
 
         if self.max_features:
-            self.features_proportion = self.max_features/self.n_features
+            self.features_proportion = self.max_features / self.n_features
 
         # Make sure the callbacks are valid
         self.callbacks = check_callback(callbacks)
@@ -1237,9 +1239,9 @@ class GAFeatureSelectionCV(BaseSearchCV):
             pop, log, gen = eaSimple(
                 pop,
                 self.toolbox,
-                cxpb=self.crossover_probability,
+                cxpb=self.crossover_adapter,
                 stats=stats,
-                mutpb=self.mutation_probability,
+                mutpb=self.mutation_adapter,
                 ngen=self.generations,
                 halloffame=hof,
                 callbacks=self.callbacks,
@@ -1254,9 +1256,9 @@ class GAFeatureSelectionCV(BaseSearchCV):
                 self.toolbox,
                 mu=self.population_size,
                 lambda_=2 * self.population_size,
-                cxpb=self.crossover_probability,
+                cxpb=self.crossover_adapter,
                 stats=stats,
-                mutpb=self.mutation_probability,
+                mutpb=self.mutation_adapter,
                 ngen=self.generations,
                 halloffame=hof,
                 callbacks=self.callbacks,
@@ -1270,9 +1272,9 @@ class GAFeatureSelectionCV(BaseSearchCV):
                 self.toolbox,
                 mu=self.population_size,
                 lambda_=2 * self.population_size,
-                cxpb=self.crossover_probability,
+                cxpb=self.crossover_adapter,
                 stats=stats,
-                mutpb=self.mutation_probability,
+                mutpb=self.mutation_adapter,
                 ngen=self.generations,
                 halloffame=hof,
                 callbacks=self.callbacks,
